@@ -1,9 +1,10 @@
 #  Fit linear mixed-effects models incorporating sampling weights
 #
 #  Uses: probability-weighted IGLS (PWIGLS)
-#' @useDynLib pwlmm
+#' @useDynLib pwlmm, .registration = TRUE
+#' @importFrom Rcpp evalCpp
 #'
-.onUnload <- function (libpath) {library.dynam.unload("pwlmm", libpath)} #Why it works (using to avoid error message)
+.onUnload <- function (libpath) {library.dynam.unload("pwlmm", libpath)}
 
 #' @export
 print.univariate <- function(x, ...){
@@ -42,6 +43,7 @@ print.univariate <- function(x, ...){
 
   cat("\n")
   cat(noquote("Note: robust standard errors"))
+  invisible(x) # <--- CRAN EXIGE ISSO EM METODOS PRINT
 }
 
 #' @export
